package com.aucma.base.service;

import java.util.List;
import com.aucma.base.domain.InspectionReport;

public interface IInspectionReportService {
    public InspectionReport selectInspectionReportByObjId(Long objId);

    public List<InspectionReport> selectInspectionReportList(InspectionReport inspectionReport);

    public int insertInspectionReport(InspectionReport inspectionReport);

    public int updateInspectionReport(InspectionReport inspectionReport);

    public int deleteInspectionReportByObjIds(Long[] objIds);

    public int deleteInspectionReportByObjId(Long objId);
}
