package com.aucma.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.base.domain.InspectionReport;
import com.aucma.base.service.IInspectionReportService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

@RestController
@RequestMapping("/base/inspectionReport" )
public class InspectionReportController extends BaseController {
    @Autowired
    private IInspectionReportService inspectionReportService;

    @PreAuthorize("@ss.hasPermi('base:inspectionReport:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(InspectionReport inspectionReport) {
        startPage();
        List<InspectionReport> list = inspectionReportService.selectInspectionReportList(inspectionReport);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('base:inspectionReport:export')" )
    @Log(title = "检验报表" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, InspectionReport inspectionReport) {
        List<InspectionReport> list = inspectionReportService.selectInspectionReportList(inspectionReport);
        ExcelUtil<InspectionReport> util = new ExcelUtil<InspectionReport>(InspectionReport. class);
        util.exportExcel(response, list, "检验报表数据" );
    }

    @PreAuthorize("@ss.hasPermi('base:inspectionReport:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(inspectionReportService.selectInspectionReportByObjId(objId));
    }

    @PreAuthorize("@ss.hasPermi('base:inspectionReport:add')" )
    @Log(title = "检验报表" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody InspectionReport inspectionReport) {
        inspectionReport.setCreatedBy(getUsername());
        inspectionReport.setCreatedTime(DateUtils.getNowDate());
        return toAjax(inspectionReportService.insertInspectionReport(inspectionReport));
    }

    @PreAuthorize("@ss.hasPermi('base:inspectionReport:edit')" )
    @Log(title = "检验报表" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody InspectionReport inspectionReport) {
        inspectionReport.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(inspectionReportService.updateInspectionReport(inspectionReport));
    }

    @PreAuthorize("@ss.hasPermi('base:inspectionReport:remove')" )
    @Log(title = "检验报表" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(inspectionReportService.deleteInspectionReportByObjIds(objIds));
    }

    @PreAuthorize("@ss.hasPermi('base:inspectionReport:list')" )
    @GetMapping("/getList" )
    public TableDataInfo getList(InspectionReport inspectionReport) {
        List<InspectionReport> list = inspectionReportService.selectInspectionReportList(inspectionReport);
        return getDataTable(list);
    }
}
